@@ -1,8 +1,11 @@
 """
 .. include:: ../README.md
 """
+from importlib_metadata import version
 import nowcastlib.rawdata
 import nowcastlib.gis
-from importlib_metadata import version
+import nowcastlib.signals
+import nowcastlib.utils
+import nowcastlib.dynlag
 
 __version__ = version(__package__)
